@@ -55,7 +55,7 @@ def parse_config():
                 file = cfg_file
                 print(f"Config file found in {cfg_file} directory.")
                 break
-        else:
+        # else:
             # print(f"Config file not found in {cfg_file} directory.")
             # print(f"Checking next directory...")
     if not config:
